summaryrefslogtreecommitdiffstats
path: root/chrome/browser/autofill/autofill_manager.h
diff options
context:
space:
mode:
authorisherman@chromium.org <isherman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-08-23 07:08:12 +0000
committerisherman@chromium.org <isherman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-08-23 07:08:12 +0000
commit7f512a0c118966c285254f037f68a952d6aeb0dc (patch)
tree4ce2954a8cc72cc3598b1c8b10a0790e35df6144 /chrome/browser/autofill/autofill_manager.h
parent70049d93a7248acfefbdf16c573fb95e32a8fdfc (diff)
downloadchromium_src-7f512a0c118966c285254f037f68a952d6aeb0dc.zip
chromium_src-7f512a0c118966c285254f037f68a952d6aeb0dc.tar.gz
chromium_src-7f512a0c118966c285254f037f68a952d6aeb0dc.tar.bz2
Add preliminary support for the autocompletetype atttribute for phone/fax prefix and suffix.
BUG=92121 TEST=unit_tests --gtest_filter=FormStructureTest.*:AutofillManagerTest.* Review URL: http://codereview.chromium.org/7694017 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@97827 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/autofill/autofill_manager.h')
-rw-r--r--chrome/browser/autofill/autofill_manager.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/chrome/browser/autofill/autofill_manager.h b/chrome/browser/autofill/autofill_manager.h
index a9bdc9f..35154c1 100644
--- a/chrome/browser/autofill/autofill_manager.h
+++ b/chrome/browser/autofill/autofill_manager.h
@@ -167,24 +167,25 @@ class AutofillManager : public TabContentsObserver,
std::vector<string16>* icons,
std::vector<int>* unique_ids);
- // Set |field| argument's value based on |type| and contents of the
- // |credit_card|.
- void FillCreditCardFormField(const CreditCard* credit_card,
+ // Set |field|'s value based on |type| and contents of the |credit_card|.
+ void FillCreditCardFormField(const CreditCard& credit_card,
AutofillFieldType type,
webkit_glue::FormField* field);
- // Set |field| argument's value based on |type| and contents of the |profile|.
- // The |variant| parameter specifies which value in a multi-valued profile.
- void FillFormField(const AutofillProfile* profile,
- AutofillFieldType type,
+ // Set |field|'s value based on |cached_field|'s type and contents of the
+ // |profile|. The |variant| parameter specifies which value in a multi-valued
+ // profile.
+ void FillFormField(const AutofillProfile& profile,
+ const AutofillField& cached_field,
size_t variant,
webkit_glue::FormField* field);
- // Set |field| argument's value for phone/fax number based on contents of the
- // |profile|. |type| is the type of the phone.
- // The |variant| parameter specifies which value in a multi-valued profile.
- void FillPhoneNumberField(const AutofillProfile* profile,
- AutofillFieldType type,
+ // Set |field|'s value for phone/fax number based on contents of the
+ // |profile|. The |cached_field| specifies the type of the phone and whether
+ // this is a phone prefix or suffix. The |variant| parameter specifies which
+ // value in a multi-valued profile.
+ void FillPhoneNumberField(const AutofillProfile& profile,
+ const AutofillField& cached_field,
size_t variant,
webkit_glue::FormField* field);